@@ -114,6 +114,7 @@ class ImageSetAdmin(OSMGeoAdmin):
         'pk',
         'name',
         'count',
+        'number_of_bands',
         'modified',
         'created',
     )
@@ -123,6 +124,7 @@ class ImageSetAdmin(OSMGeoAdmin):
     )
     list_filter = MODIFIABLE_FILTERS  # (ImageSetSpatialFilter, )
     inlines = (ImageSetSpatialInline,)
+    raw_id_fields = ('images',)
 
 
 class BandMetaInline(admin.StackedInline):
@@ -161,7 +163,6 @@ class ImageMetaInline(admin.StackedInline):
         'created',
     )
     readonly_fields = (
-        'number_of_bands',
         'parent_image',
         'height',
         'width',
@@ -169,10 +170,7 @@ class ImageMetaInline(admin.StackedInline):
         'modified',
         'created',
     )
-    list_filter = MODIFIABLE_FILTERS + (
-        'number_of_bands',
-        'driver',
-    )
+    list_filter = MODIFIABLE_FILTERS + ('driver',)
 
 
 @admin.register(Image)
@@ -180,6 +178,7 @@ class ImageAdmin(OSMGeoAdmin, _FileGetNameMixin):
     list_display = (
         'pk',
         'get_name',
+        'number_of_bands',
         'status',
         'modified',
         'created',
@@ -200,3 +199,4 @@ class ImageAdmin(OSMGeoAdmin, _FileGetNameMixin):
         ImageMetaInline,
         BandMetaInline,
     )
+    raw_id_fields = ('file',)
