@@ -1,25 +1,7 @@
-import re
-
 import pytest
-from rgd.models import ChecksumFile
 from rgd_imagery.stac.serializers import ItemSerializer
 
 
-@pytest.mark.django_db(transaction=True)
-def test_stac_browser_limit(settings, admin_api_client, sample_raster_url):
-    ChecksumFile.objects.update(collection=None)
-    response = admin_api_client.get('/api/stac/collection/default/items')
-    assert response.status_code == 200
-    settings.RGD_STAC_BROWSER_LIMIT = 1
-    with pytest.raises(
-        ValueError,
-        match=re.escape(
-            "'RGD_STAC_BROWSER_LIMIT' (1) exceeded. Requested collection with 3 items."
-        ),
-    ):
-        response = admin_api_client.get('/api/stac/collection/default/items')
-
-
 @pytest.mark.django_db(transaction=True)
 def test_raster_stac_serializer_simple(sample_raster_url_single):
     data = ItemSerializer().to_representation(sample_raster_url_single)
@@ -50,5 +32,5 @@ def test_eo_serialize(sample_raster_url):
 
 @pytest.mark.django_db(transaction=True)
 def test_optimized_query(admin_api_client, sample_raster_url, django_assert_num_queries):
-    with django_assert_num_queries(2):
+    with django_assert_num_queries(1):
         admin_api_client.get('/api/stac/collection/default/items')
